TMGMT Blackbird
===============
This module provides integration with the Blackbird translation provider for
the Translation Management Tool project.

Blackbird is a Content Orchestration Platform designed to automate workflows,
integrate systems, and enable AI. It’s the automation backbone for multilingual
global content.


Requirements
------------
The module depends on the
[Translation Management (TMGMT) module](https://www.drupal.org/project/tmgmt).

Installation
------------
Install the module as you would normally install a contributed Drupal module.
Visit [Installing contributed modules](https://www.drupal.org/docs/8/extending-drupal-8/installing-contributed-modules)
for further information.

Configuration
-------------
Go to `/admin/tmgmt/translators` and configure the `Blackbird` plugin. On the
configuration form, you will need to provide the following information:
- API Key: The API key used by Blackbird to process translations jobs. The API
  key needs to be copied to the Blackbird platform settings to complete the
  integration.
- To prevent having to manually accept all translations, you can enable the
  `Auto accept finished translations` setting. This will automatically accept
  all translations when they are completed.

Translation jobs
----------------
When creating a new translation job, you can select the `Blackbird` translator
to process the job. Blackbird will then automatically process the job and post
the translations back when they are done. The module will expose the following
endpoints for `Blackbird` to interact with the translation jobs:

### Available languages
<details>
  <summary>
    <code>GET</code> - 
    <code><b>/api/tmgmt/blackbird/languages</b></code> - 
    <code>Returns a list of available languages.</code>
  </summary>

  **Authentication**  
  `x-api-key` header with the API key.

  **Parameters**  
  None
  
  **Response**  
  JSON array with the following data for each language:
  - `code`: The language code
  - `name`: The language name
</details>


### Available translation jobs
<details>
  <summary>
    <code>GET</code> - 
    <code><b>/api/tmgmt/blackbird/jobs</b></code> - 
    <code>Returns a list of all open jobs.</code>
  </summary>

  **Authentication**  
  `x-api-key` header with the API key.

  **Parameters**  
  - `created`: Filter by created date. Must be a valid timestamp.
  - `source`: Filter by source language. Must be a valid language code.
  - `target`: Filter by target language. Must be a valid language code.
  - `state`: Filter by state. Must be one of *active* / *aborted* / *completed*.
  
  **Response**  
  JSON array with the following data for each job:
  - `id`: The Job ID
  - `name`: The Job name
  - `source`: The source language code
  - `target`: The target language code
  - `created`: The timestamp when the job was created
</details>


### Translation job
<details>
  <summary>
    <code>GET</code> - 
    <code><b>/api/tmgmt/blackbird/job/{id}</b></code> - 
    <code>Returns the HTML output for a translation job.</code>
  </summary>

  **Authentication**  
  `x-api-key` header with the API key.

  **Parameters**  
  - `id`: The Job ID

  **Response**  
  The HTML output for the translation job.
</details>

<details>
  <summary>
    <code>POST</code> - 
    <code><b>/api/tmgmt/blackbird/job/{id}</b></code> - 
    <code>Accepts the HTML input for a translation job.</code>
  </summary>

  **Authentication**  
  `x-api-key` header with the API key.

  **Parameters**  
  - `id`: The Job ID

  **Response**  
  The HTML input for the translation job
</details>
