<?php

namespace Drupal\tmgmt_blackbird;

use Drupal\Component\Utility\Crypt;
use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\InvokeCommand;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\tmgmt\TranslatorPluginUiBase;

/**
 * The Blackbird translator configuration form.
 */
class BlackbirdTranslatorUi extends TranslatorPluginUiBase {

  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state): array {
    $form = parent::buildConfigurationForm($form, $form_state);

    /** @var \Drupal\tmgmt\Form\TranslatorForm $form_object */
    $form_object = $form_state->getFormObject();
    /** @var \Drupal\tmgmt\TranslatorInterface $translator */
    $translator = $form_object->getEntity();

    $form['api_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Blackbird API Key'),
      '#description' => $this->t('Please enter the API key that Blackbird can use to access translation jobs and return the translated results. Make sure to copy the key correctly and add it to the Blackbird settings.'),
      '#default_value' => $translator->getSetting('api_key') ?: Crypt::randomBytesBase64(),
      '#required' => TRUE,
    ];

    $form['regenerate'] = [
      '#type' => 'submit',
      '#value' => $this->t('Generate new API key'),
      '#limit_validation_errors' => [['settings']],
      '#ajax' => [
        'callback' => [$this, 'ajaxRegenerateApiKey'],
      ],
    ];

    return $form;
  }

  /**
   * AJAX callback to regenerate and API key.
   *
   * @param array $form
   *   The form array.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The form state.
   *
   * @return \Drupal\Core\Ajax\AjaxResponse
   *   The AJAX response to update the API key.
   */
  public function ajaxRegenerateApiKey(array $form, FormStateInterface $form_state): AjaxResponse {
    return (new AjaxResponse())
      ->addCommand(new InvokeCommand("[data-drupal-selector=\"edit-settings-api-key\"]", 'val', [Crypt::randomBytesBase64()]));
  }

}
