<?php

namespace Drupal\tmgmt_blackbird\Plugin\tmgmt\Translator;

use Drupal\tmgmt\JobInterface;
use Drupal\tmgmt\Translator\AvailableResult;
use Drupal\tmgmt\Translator\TranslatableResult;
use Drupal\tmgmt\TranslatorInterface;
use Drupal\tmgmt\TranslatorPluginBase;

/**
 * The Blackbird translator plugin.
 *
 * @TranslatorPlugin(
 *   id = "blackbird",
 *   label = @Translation("Blackbird"),
 *   description = @Translation("Blackbird Translator service."),
 *   map_remote_languages = FALSE,
 *   ui = "Drupal\tmgmt_blackbird\BlackbirdTranslatorUi",
 *   logo = "icons/blackbird.svg",
 * )
 */
class BlackbirdTranslator extends TranslatorPluginBase {

  /**
   * {@inheritdoc}
   */
  public function checkAvailable(TranslatorInterface $translator): AvailableResult {
    // We assume that the translation service is always available.
    return AvailableResult::yes();
  }

  /**
   * {@inheritdoc}
   */
  public function checkTranslatable(TranslatorInterface $translator, JobInterface $job): TranslatableResult {
    // We assume everything is translatable.
    return TranslatableResult::yes();
  }

  /**
   * {@inheritdoc}
   */
  public function hasCheckoutSettings(JobInterface $job): bool {
    // We do not require additional settings for translation jobs.
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function requestTranslation(JobInterface $job): void {
    $this->requestJobItemsTranslation($job->getItems());
    if (!$job->isRejected()) {
      $job->submitted('The translation job has been submitted.');
    }
  }

  /**
   * {@inheritdoc}
   */
  public function requestJobItemsTranslation(array $job_items): void {
    // The translation jobs are pulled by Blackbird. We do not need to do
    // anything here.
  }

}
